"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterArguments = exports.extend = exports.reload = exports.reloadFromConfigFile = exports.cliArguments = void 0;
const file = require("file-exists");
const fs = require("fs");
const dotenv_1 = require("dotenv");
/**
 * A global variable containing a parsed list of loaded CLI arguments by preferred prefix (--) and separator (=)
 */
exports.cliArguments = loadArguments();
/**
 * Reloading CLI arguments via Config file
 * @param filePath The file path
 */
function reloadFromConfigFile(filePath) {
    const file = fs.readFileSync(filePath);
    const parsedContens = (0, dotenv_1.parse)(file);
    console.log(parsedContens);
    exports.cliArguments = parsedContens;
}
exports.reloadFromConfigFile = reloadFromConfigFile;
/**
 * Reloading the CLI arguments
 */
function reload() {
    exports.cliArguments = loadArguments();
}
exports.reload = reload;
/**
 * Extending the existing cli arguments with given JS object
 * @param args A given JS object of arguments
 */
function extend(args) {
    Object.assign(exports.cliArguments, args);
}
exports.extend = extend;
/**
 * Loading the filtered arguments
 */
function loadArguments() {
    let config = file.sync(`${process.env.INIT_CWD}/cli.config.json`) ? require(`${process.env.INIT_CWD}/cli.config.json`) : { prefix: '--', separator: '=' };
    config = Object.assign(config, filterArguments('--cli-', '='));
    return filterArguments(config.prefix, config.separator);
}
/**
 * Filtering only relevant arguments by preferred prefix (--) and separator (=)
 * @param prefix The prefix of the argument
 * @param separator The separator of the argument
 */
function filterArguments(prefix, separator) {
    const finalArgumentsList = {};
    const argumentsList = filterer(prefix, separator);
    for (const argument of argumentsList) {
        const splitArgument = (separator !== '') ? argument.split(separator) : [argument, undefined];
        const name = splitArgument[0].replace(prefix, '');
        const value = (splitArgument[1] !== undefined) ? splitArgument[1] : '';
        finalArgumentsList[name] = value;
    }
    return finalArgumentsList;
}
exports.filterArguments = filterArguments;
/**
 * A filter function to filter by dynamic prefix & separator
 * @param prefix The prefix of the argument
 * @param separator The separator of the argument
 */
function filterer(prefix, separator) {
    if (prefix !== '' && separator === '')
        return process.argv.filter((argument) => argument.startsWith(prefix));
    else if (prefix === '' && separator !== '')
        return process.argv.filter((argument) => argument.indexOf(separator) !== -1);
    else if (prefix !== '' && separator !== '')
        return process.argv.filter((argument) => argument.startsWith(prefix) && argument.indexOf(separator) !== -1);
    return process.argv;
}
